SWDEV-505853 - Fix Unit_hipMemPoolApi_BasicAlloc in mgpu
Unit_hipMemPoolApi_BasicAlloc expects to work on device 0, but other
tests will set not-0 devices in mgpu. This leads to hang of
Unit_hipMemPoolApi_BasicAlloc. Fix by set device 0 in head code
of Unit_hipMemPoolApi_BasicAlloc.
SWDEV-508872 - Fix Perf_hipPerfMemFill_test
When mem size is 2G, the test is so slow that it looks like stuckness.
Set top mem size to 1G can make the test pass in an acceptiable time.
Change-Id: Ie26dbf597e5ba8cb898d1aae5ed5ecf0267c3228
[ROCm/hip-tests commit: 94eea4db59]
This commit is contained in:
@@ -84,7 +84,7 @@ template<class T>
|
||||
class hipPerfMemFill {
|
||||
private:
|
||||
static constexpr int NUM_START = 27;
|
||||
static constexpr int NUM_SIZE = 5;
|
||||
static constexpr int NUM_SIZE = 4;
|
||||
static constexpr int NUM_ITER = 10;
|
||||
static constexpr double NUM_1GB = 1024.0 * 1024.0 * 1024.0;
|
||||
size_t totalSizes_[NUM_SIZE];
|
||||
@@ -96,7 +96,7 @@ class hipPerfMemFill {
|
||||
public:
|
||||
hipPerfMemFill() {
|
||||
for (int i = 0; i < NUM_SIZE; i++) {
|
||||
// 128M, 256M, 512M, 1024M, 2048M
|
||||
// 128M, 256M, 512M, 1024M
|
||||
totalSizes_[i] = 1ull << (i + NUM_START);
|
||||
}
|
||||
}
|
||||
|
||||
@@ -137,6 +137,8 @@ __global__ void kernel500ms_gfx11(float* hostRes, int clkRate) {
|
||||
|
||||
TEST_CASE("Unit_hipMemPoolApi_BasicAlloc") {
|
||||
int mem_pool_support = 0;
|
||||
HIP_CHECK(hipSetDevice(0));
|
||||
|
||||
HIP_CHECK(hipDeviceGetAttribute(&mem_pool_support, hipDeviceAttributeMemoryPoolsSupported, 0));
|
||||
if (!mem_pool_support) {
|
||||
SUCCEED("Runtime doesn't support Memory Pool. Skip the test case.");
|
||||
|
||||
Reference in New Issue
Block a user